@@ -648,8 +648,6 @@ GnomeVFSResult upnpav_determine_fileinfo(UPnPAVNodeData *data, GnomeVFSFileInfo*
 	
 	g_return_val_if_fail(data != NULL, GNOME_VFS_ERROR_NOT_FOUND);
 	
-	memset(file_info, sizeof(GnomeVFSFileInfo), 0);
-	
 	file_info->valid_fields = GNOME_VFS_FILE_INFO_FIELDS_NONE;
 	upnpav_set_global_file_info(file_info);
 	
@@ -1174,6 +1172,7 @@ static gchar *upnpav_get_extension_from_mime_type(const gchar *mime_type)
 		{ .mime = NULL, .extension = NULL }
 	};
 	gchar *extension = NULL;
+	gint idx = 0;
 #ifdef GUPNP_USE_MAEMO
 	GSList *patterns = hildon_mime_patterns_get_for_mime_type(mime_type,
 								 NULL);
@@ -1197,7 +1196,7 @@ static gchar *upnpav_get_extension_from_mime_type(const gchar *mime_type)
 	if (!extension)
 	{
 		/* Last resolt: try to guess correct extension with table */
-		for (gint idx = 0; ext_guess_map[idx].mime != NULL; idx++)
+		for (idx = 0; ext_guess_map[idx].mime != NULL; idx++)
 		{
 			if (strcmp(ext_guess_map[idx].mime, mime_type) == 0)
 			{
@@ -1585,8 +1584,8 @@ static gboolean upnpav_determine_resource(UPnPAVNodeData *data, CgXmlNode *conte
 	if (attr != NULL)
 	{
 		/* Get size for the data */
-		data->size = strtoull(cg_xml_node_getvalue(attr), 
-				      NULL, 10);
+		data->size = g_ascii_strtoull(cg_xml_node_getvalue(attr),
+					      NULL, 10);
 	}
 	/* TODO: we should check also storageUsed property! */
 #else
